LineOffset class

A class that represents a line offset The line is represented by two points, start and end

Constructors

LineOffset({required Offset start, required Offset end})
const

Properties

end → Offset
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Offset
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited