Crossword class
Represents a widget for a crossword game board.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- Crossword
Constructors
-
Crossword({Key? key, required List<
List< letters, required Offset spacing, bool? drawCrossLine, bool? drawHorizontalLine, bool? drawVerticalLine, required List<String> >String> hints, LineDecoration? lineDecoration, TextStyle? textStyle, List<LineOffset> initialLineList = const [], bool? acceptReversedDirection = false, bool? transposeMatrix = false, bool? allowOverlap = false, bool? addIncorrectWord = true, dynamic onLineUpdate(String word, List<String> , bool)?, List<Color> ? invalidLineColors, RevealLetterDecoration? revealLetterDecoration = const RevealLetterDecoration(shakeOffset: Offset(20, 50), scaleFactor: 2), bool? updateStateWithParent = false, int minimumWordLength = 3, LetterPopDecoration letterPopDecoration = const LetterPopDecoration()}) -
const
Properties
- acceptReversedDirection → bool?
-
it is used to determine whether the line can be drawn in the opposite direction
final
- addIncorrectWord → bool?
-
decides the incorrect words to be added to the list or not
final
- allowOverlap → bool?
-
it is used to determine whether the line can be drawn on top of another line
final
- drawCrossLine → bool?
-
final
- drawHorizontalLine → bool?
-
final
- drawVerticalLine → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hints
→ List<
String> -
final
-
initialLineList
→ List<
LineOffset> -
final
-
invalidLineColors
→ List<
Color> ? -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- letterPopDecoration → LetterPopDecoration
-
final
-
letters
→ List<
List< String> > -
final
- lineDecoration → LineDecoration?
-
final
- minimumWordLength → int
-
final
-
onLineUpdate
→ dynamic Function(String word, List<
String> , bool)? -
final
- revealLetterDecoration → RevealLetterDecoration?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → Offset
-
final
- textStyle → TextStyle?
-
final
- transposeMatrix → bool?
-
final
- updateStateWithParent → bool?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → CrosswordState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited